==> ignite-core-2.6.0-sources.jar: org/apache/ignite/internal/processors/service/PreparedConfigurations.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.processors.service;

import java.util.List;
import org.apache.ignite.internal.util.typedef.internal.S;
import org.apache.ignite.services.ServiceConfiguration;

/**
 * Result of services validation before deployment.
 */
class PreparedConfigurations {
    /** */
    final List<ServiceConfiguration> cfgs;

    /** */
    final List<GridServiceDeploymentFuture> failedFuts;

    /**
     * @param cfgs Configurations to deploy.
     * @param failedFuts Finished futures for failed configurations.
     */
    PreparedConfigurations(List<ServiceConfiguration> cfgs, List<GridServiceDeploymentFuture> failedFuts) {
        this.cfgs = cfgs;
        this.failedFuts = failedFuts;
    }

    /** {@inheritDoc} */
    @Override public String toString() {
        return S.toString(PreparedConfigurations.class, this);
    }
}

==> ignite-core-2.8.0-sources.jar: org/apache/ignite/internal/processors/service/PreparedConfigurations.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.processors.service;

import java.io.Serializable;
import java.util.List;
import org.apache.ignite.internal.util.typedef.internal.S;
import org.apache.ignite.services.ServiceConfiguration;

/**
 * Result of services validation before deployment.
 */
class PreparedConfigurations<T extends Serializable> {
    /** */
    final List<ServiceConfiguration> cfgs;

    /** */
    final List<GridServiceDeploymentFuture<T>> failedFuts;

    /**
     * @param cfgs Configurations to deploy.
     * @param failedFuts Finished futures for failed configurations.
     */
    PreparedConfigurations(List<ServiceConfiguration> cfgs, List<GridServiceDeploymentFuture<T>> failedFuts) {
        this.cfgs = cfgs;
        this.failedFuts = failedFuts;
    }

    /** {@inheritDoc} */
    @Override public String toString() {
        return S.toString(PreparedConfigurations.class, this);
    }
}
